"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert = require("assert");
const sinon = require("sinon");
const fs_1 = require("../fs");
const memfs_1 = require("../memfs");
const packages_1 = require("../packages");
const updater_1 = require("../updater");
const fs_helpers_1 = require("./fs-helpers");
describe('packages.ts', () => {
    describe('extractDefinitelyTypedPackageName()', () => {
        it('should return the @types package name for a file in DefinitelyTyped', () => {
            const packageName = packages_1.extractDefinitelyTypedPackageName('file:///types/node/index.d.ts');
            assert.equal(packageName, '@types/node');
        });
        it('should return undefined otherwise', () => {
            const packageName = packages_1.extractDefinitelyTypedPackageName('file:///package.json');
            assert.strictEqual(packageName, undefined);
        });
    });
    describe('extractNodeModulesPackageName()', () => {
        it('should return the package name for a file in node_modules', () => {
            const packageName = packages_1.extractNodeModulesPackageName('file:///foo/node_modules/bar/baz/test.ts');
            assert.equal(packageName, 'bar');
        });
        it('should return the package name for a file in a scoped package in node_modules', () => {
            const packageName = packages_1.extractNodeModulesPackageName('file:///foo/node_modules/@types/bar/baz/test.ts');
            assert.equal(packageName, '@types/bar');
        });
        it('should return the package name for a file in nested node_modules', () => {
            const packageName = packages_1.extractNodeModulesPackageName('file:///foo/node_modules/bar/node_modules/baz/test.ts');
            assert.equal(packageName, 'baz');
        });
        it('should return undefined otherwise', () => {
            const packageName = packages_1.extractNodeModulesPackageName('file:///foo/bar');
            assert.strictEqual(packageName, undefined);
        });
    });
    describe('PackageManager', () => {
        it('should register new packages as they are added to InMemoryFileSystem', () => __awaiter(this, void 0, void 0, function* () {
            const remoteFs = new fs_helpers_1.MapAsynchronousFileSystem(new Map([['file:///foo/package.json', '{}']]));
            const fs = new fs_1.InMemoryFileSystem();
            const memfs = new memfs_1.OverlayFileSystem(fs, '/');
            const updater = new updater_1.RemoteFileSystemUpdater(remoteFs, fs);
            const packageManager = new packages_1.PackageManager(updater, memfs);
            const listener = sinon.spy();
            packageManager.on('parsed', listener);
            const packageJsonEnsured = updater.ensure('file:///foo/package.json').toPromise();
            yield packageJsonEnsured;
            const packages = Array.from(packageManager.packageJsonUris());
            assert.deepEqual(packages, ['file:///foo/package.json']);
            sinon.assert.calledOnce(listener);
            sinon.assert.alwaysCalledWith(listener, 'file:///foo/package.json', {});
        }));
    });
});
//# sourceMappingURL=packages.test.js.map