"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const rimraf = require("rimraf");
const temp = require("temp");
const fs_1 = require("../fs");
const typescript_service_1 = require("../typescript-service");
const util_1 = require("../util");
const typescript_service_helpers_1 = require("./typescript-service-helpers");
function ensureDirectoryExistence(filePath) {
    const dirname = path.dirname(filePath);
    if (fs.existsSync(dirname)) {
        return;
    }
    ensureDirectoryExistence(dirname);
    fs.mkdirSync(dirname);
}
describe('TypeScriptService', () => __awaiter(this, void 0, void 0, function* () {
    for (const rootUri of ['file:///', 'file:///c:/foo/bar/', 'file:///foo/bar/']) {
        describe(`rootUri ${rootUri}`, () => {
            typescript_service_helpers_1.describeTypeScriptService({
                createService: (client, options) => __awaiter(this, void 0, void 0, function* () { return new typescript_service_1.TypeScriptService(client, options); }),
                clientCapabilities: {
                    xcontentProvider: true,
                    xfilesProvider: true,
                },
                rootUri,
            });
        });
    }
    const temporaryDir = temp.mkdirSync('local-fs') + '/';
    describe(`local filesystem`, () => {
        const createService = (client, options) => __awaiter(this, void 0, void 0, function* () {
            const remoteFileSystem = new fs_1.RemoteFileSystem(client);
            yield new Promise((resolve, reject) => {
                rimraf(temporaryDir, err => (err ? reject(err) : resolve()));
            });
            yield remoteFileSystem
                .getWorkspaceFiles()
                .flatMap((fileUri) => remoteFileSystem.getTextDocumentContent(fileUri).map((content) => ({ fileUri, content })))
                .do((fileContent) => {
                const fileName = util_1.uri2path(fileContent.fileUri);
                ensureDirectoryExistence(fileName);
                fs.writeFileSync(fileName, fileContent.content, 'utf8');
            })
                .toPromise();
            return new typescript_service_1.TypeScriptService(client, Object.assign({ strict: false }, options));
        });
        const options = { createService, clientCapabilities: {}, rootUri: util_1.path2uri(temporaryDir) };
        typescript_service_helpers_1.describeTypeScriptService(options);
    });
    after(() => __awaiter(this, void 0, void 0, function* () {
        yield new Promise((resolve, reject) => {
            rimraf(temporaryDir, err => (err ? reject(err) : resolve()));
        });
    }));
}));
//# sourceMappingURL=typescript-service.test.js.map